/*
 * domain.h
 *
 * Domain module defines entities & value objects.
 *
 *  Created on: Mar 21, 2015
 *      Author: ilazar
 */

#ifndef DOMAIN_H_
#define DOMAIN_H_

#include "utils/debug.h"
#include <iostream>
#include <string>

using namespace std;

namespace Todo {

/**
 * Enumeration representing task status values.
 */
enum TaskStatus {
	ACTIVE, DONE
};

/**
 * Represents a task (text: string, status: ACTIVE/DONE).
 */
class Task {
private:
	string _text;
	TaskStatus _status;
	friend ostream& operator<<(ostream& out, const Task& task);
	friend istream& operator>>(istream& out, Task& task);
public:
	Task() :
			_text(""), _status(ACTIVE) {
		debug("Task()");
	}
	Task(const string& text, const TaskStatus status) :
			_text(text), _status(status) {
		debug("Task(const string& %s, const TaskStatus)", text.c_str());
	}
	~Task() {
		debug("~Task()");
	}

	bool operator<(const Task& other) {
		debug("bool Task::operator<(const string&)");
		return _text < other._text;
	}

	bool is_valid() const {
		debug("bool Task::is_valid()");
		return _text.size() > 0;
	}
};

/**
 * Writes a task to ostream.
 */
ostream& operator<<(const ostream& out, const Task& task);

/**
 * Reads a task from istream.
 */
istream& operator>>(const istream& out, Task& task);

}
#endif /* DOMAIN_H_ */
