/*
 * repository.h
 *
 * Represents the persistence infrastructure used by this app.
 *
 *  Created on: Mar 21, 2015
 *      Author: ilazar
 */

#ifndef REPOSITORY_H_
#define REPOSITORY_H_

#include "domain.h"
#include "utils/debug.h"
#include <fstream>
#include <exception>
#include <stdexcept>
#include <list>

namespace Todo {

template<class Entity>
class Repository {
	const char* _filename;

public:
	/** Initializes a task repository.
	 *
	 * Pre: filename must not be null.
	 */
	Repository(const char* filename) :
			_filename(filename) {
	}

	/**
	 * Saves a task.
	 * If operation fails due to I/O errors, runtime_error is thrown.
	 */
	void save(Entity& entity) const throw (runtime_error);

	/**
	 * Returns the task list.
	 *
	 * If the operation succeeds, a task list is returned,
	 * otherwise runtime_error is thrown.
	 */
	list<Entity>* find_all() const throw (runtime_error);
};

template<class Entity>
void Repository<Entity>::save(Entity& entity) const throw (runtime_error) {
	debug("void Repository::save(Entity& entity) const");
	try {
		ofstream f(_filename, ofstream::app);
		f << entity;
		f.close();
	} catch (...) {
		throw runtime_error("Cannot write to todo file");
	}
}

template<class Entity>
list<Entity>* Repository<Entity>::find_all() const throw (runtime_error) {
	debug("Vector<Entity>& Repository::find_all() const");
	list<Entity>* entities = new list<Entity>();
	try {
		ifstream f(_filename, ifstream::in);
		while (!f.eof()) {
			Entity entity;
			f >> entity;
			entities->push_back(entity);
		}
		f.close();
		return entities;
	} catch (...) {
		delete entities;
		throw runtime_error("Cannot read from todo file");
	}
}

}
#endif /* REPOSITORY_H_ */
