#include "ui.h"
#include "utils/debug.h"
#include <string>
#include <exception>
#include <assert.h>
#include <iostream>
#include <list>

using namespace std;

namespace Todo {
/**
 * Constants used for commands.
 */
static const string PROMPT = ">";
static const string CMD_ADD = "add";
static const string CMD_list = "list";
static const string CMD_EXIT = "exit";

void TodoCLI::run() {
	debug("TodoCLI::run");
	while (true) {
		debug("read command");
		string user_command;
		cout << PROMPT;
		cin >> user_command;
		if (user_command.find(CMD_ADD) != string::npos) {
			string text;
			cin >> text;
			add_task(text);
		} else if (user_command.find(CMD_list) != string::npos) {
			list_tasks();
		} else if (user_command.find(CMD_EXIT) != string::npos) {
			cout << "Bye" << endl;
			break;
		} else {
			cout << "Unknown command" << endl;
		}
	}
}

void TodoCLI::add_task(const string& text) {
	debug("TodoCLI::add_task(const string&)");
	try {
		const Task task = _todo_manager.create_task(text);
		cout << task << " created" << endl;
	} catch (logic_error& e) {
		cout << e.what() << endl;
	} catch (exception& unexpected) {
		cout << unexpected.what() << endl;
	}
}

void TodoCLI::list_tasks() {
	debug("list tasks");
	try {
		list<Task> tasks = _todo_manager.get_tasks();
		for (list<Task>::iterator it = tasks.begin(); it != tasks.end(); ++it) {
			cout << *it << endl;
		}
	} catch (exception& unexpected) {
		cout << unexpected.what() << endl;
	}
}

}
