/*
 * ui.h
 *
 *  Created on: Mar 21, 2015
 *      Author: ilazar
 */

#ifndef UI_H_
#define UI_H_

#include "service.h"
#include "utils/debug.h"
#include <string>

namespace Todo {

/**
 * Provides operations on tasks using a CLI (Command-Line Interface) as follows:
 * > add text - adds a new active task having a given text
 * > list - shows task list
 * > exit - exits the program
 */
class TodoCLI {

public:
	TodoCLI(TodoManager& todo_manager) :
			_todo_manager(todo_manager) {
		debug("TodoCLI(const TodoManager&)");
	}

	~TodoCLI() {
		debug("~TodoCLI()");
	}

	/**
	 * Provides the CLI on tasks, delegating the operations to a manager (domain controller).
	 */
	void run();
private:
	TodoManager& _todo_manager;

	/**
	 * Adds a new ACTIVE Task having a given text.
	 * If any I/O or validation errors occur, the user is informed and the instance is not added.
	 */
	void add_task(const string& text);

	/**
	 * Shows the task list.
	 *
	 * If I/O errors occur, the user is informed.
	 */
	void list_tasks();
};

}
#endif /* UI_H_ */
